package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseShutType;
import com.aucma.dms.service.IDmsBaseShutTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 停机类型信息Controller
 * 
 * @author Open Platform
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/dms/shutType")
public class DmsBaseShutTypeController extends BaseController
{
    @Autowired
    private IDmsBaseShutTypeService dmsBaseShutTypeService;

    /**
     * 查询停机类型信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:shutType:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseShutType dmsBaseShutType)
    {
        startPage();
        List<DmsBaseShutType> list = dmsBaseShutTypeService.selectDmsBaseShutTypeList(dmsBaseShutType);
        return getDataTable(list);
    }

    /**
     * 导出停机类型信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:shutType:export')" )
    ////@Log(title = "停机类型信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseShutType dmsBaseShutType)
    {
        List<DmsBaseShutType> list = dmsBaseShutTypeService.selectDmsBaseShutTypeList(dmsBaseShutType);
        ExcelUtil<DmsBaseShutType> util = new ExcelUtil<DmsBaseShutType>(DmsBaseShutType.class);
        util.exportExcel(response, list, "停机类型信息数据");
    }

    /**
     * 获取停机类型信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:shutType:query')" )
    @GetMapping(value = "/{shutTypeId}")
    public AjaxResult getInfo(@PathVariable("shutTypeId") Long shutTypeId)
    {
        return success(dmsBaseShutTypeService.selectDmsBaseShutTypeByShutTypeId(shutTypeId));
    }

    /**
     * 新增停机类型信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:shutType:add')" )
    ////@Log(title = "停机类型信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseShutType dmsBaseShutType)
    {
        return toAjax(dmsBaseShutTypeService.insertDmsBaseShutType(dmsBaseShutType));
    }

    /**
     * 修改停机类型信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:shutType:edit')" )
    ////@Log(title = "停机类型信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseShutType dmsBaseShutType)
    {
        return toAjax(dmsBaseShutTypeService.updateDmsBaseShutType(dmsBaseShutType));
    }

    /**
     * 删除停机类型信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:shutType:remove')" )
    ////@Log(title = "停机类型信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{shutTypeIds}")
    public AjaxResult remove(@PathVariable Long[] shutTypeIds)
    {
        return toAjax(dmsBaseShutTypeService.deleteDmsBaseShutTypeByShutTypeIds(shutTypeIds));
    }
}
